@@ -1,5 +1,5 @@
 from PyQt6.QtCore import Qt, QObject, QEvent, QSize
-from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView, QApplication, QStyle, QStyledItemDelegate, QScrollArea, QSizePolicy
+from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView, QApplication, QStyle, QStyledItemDelegate, QScrollArea
 from PyQt6.QtGui import QIcon, QTextDocument
 import re
 import requests
@@ -343,10 +343,10 @@ def create_button(
         padding_bottom = padding_bottom,
         disabled_border_width = disabled_border_width,
         alignment = alignment,
+        word_wrap = True,
         transparent_for_mouse = True,
         math_expression = math_expression
     )
-    label.setWordWrap(True)
     main_layout.addWidget(label)
     button.setFixedHeight(main_layout.sizeHint().height() + 2 * border_width)
     padding_left_value = padding_left if padding_left is not None else padding
@@ -790,6 +790,7 @@ def create_checkbox(
     return check_box
 
 def create_information_message_box(
+    window,
     text,
     left_margin = 25,
     top_margin = 25,
@@ -834,13 +835,14 @@ def create_information_message_box(
     button_disabled_background_color = "#2d2d2d",
     button_disabled_border_width = 2,
     button_disabled_border_color = "#4a4a4a",
-    fixed_width = 360,
+    fixed_width = None,
     math_expression = False,
     parent = None
 ):
     message_box = QDialog(parent)
     message_box.setObjectName("message_box")
     message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
+    fixed_width = get_responsive_width(window, 4)
     if fixed_width is not None: message_box.setFixedWidth(fixed_width)
     style_sheet = f"""
         QDialog#message_box {{
@@ -868,11 +870,12 @@ def create_information_message_box(
         border_width = label_border_width,
         border_color = label_border_color,
         border_radius = label_border_radius,
+        alignment = "center",
         word_wrap = True,
-        math_expression = math_expression
+        math_expression = math_expression,
+        parent = message_box
     )
     main_layout.addWidget(text_label)
-    text_label.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
     accept_button = create_button(
         text = button_text,
         font_family = button_font_family,
@@ -903,6 +906,7 @@ def create_information_message_box(
     return message_box
     
 def create_confirmation_message_box(
+    window,
     text,
     left_margin = 25,
     top_margin = 25,
@@ -947,13 +951,14 @@ def create_confirmation_message_box(
     button_disabled_background_color = "#2d2d2d",
     button_disabled_border_width = 2,
     button_disabled_border_color = "#4a4a4a",
-    fixed_width = 360,
+    fixed_width = None,
     math_expression = False,
     parent = None
 ):
     confirm_message_box = QDialog(parent)
     confirm_message_box.setObjectName("confirm_message_box")
     confirm_message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
+    fixed_width = get_responsive_width(window, 3)
     if fixed_width is not None: confirm_message_box.setFixedWidth(fixed_width)
     style_sheet = f"""
         QDialog#confirm_message_box {{
@@ -981,11 +986,12 @@ def create_confirmation_message_box(
         border_width = label_border_width,
         border_color = label_border_color,
         border_radius = label_border_radius,
+        alignment = "center",
         word_wrap = True,
-        math_expression = math_expression
+        math_expression = math_expression,
+        parent = confirm_message_box
     )
     main_layout.addWidget(text_label)
-    text_label.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
     buttons_layout = QHBoxLayout()
     main_layout.addLayout(buttons_layout)
     buttons_layout.setSpacing(button_spacing)
@@ -1205,6 +1211,7 @@ def confirm_exit(
     button_disabled_border_color = "#4a4a4a"
 ):
     confirmation_message_box = create_confirmation_message_box(
+        window = window,
         text = "¿Está seguro de querer salir del programa?",
         background_color = background_color,
         border_width = border_width,
